@@ -50,5 +50,15 @@ class LanzouDirectory(BaseTable):
         data = [line for line in engine.execute(s)]
         return len(data) == 1
 
+    def file_fid(self, path):
+        s = select(self.table.columns).where(self.table.columns.path == path)
+        data = [line for line in engine.execute(s)]
+
+        if len(data) == 1:
+            return data[0]['fid']
+        else:
+            return -1
+
     def sync(self, path):
-        self.drive.sync_files(path, self.fid, remove_local=True)
+        def filter_fun(x): return x.endswith('.csv')
+        self.drive.sync_files(path, self.fid, remove_local=True, filter_fun=filter_fun)
