@@ -173,7 +173,11 @@ class LoadTradeKline:
                 } for trade in trades])
 
                 time.sleep(int(self.exchange.rateLimit / 1000))
+                if len(result) > 30000:
+                    self.table.insert(result)
+                    result.clear()
             except ccxt.NetworkError as e:
                 print(type(e).__name__, str(e))
                 self.exchange.sleep(10000)
-        self.table.insert(result)
+        if len(result) > 0:
+            self.table.insert(result)
