@@ -13,7 +13,7 @@ logger.setLevel(logging.DEBUG)
 
 
 def init():
-    uri = "mysql+pymysql://notecoin:notecoin@127.0.0.1:3306/notecoin?charset=utf8"
+    uri = "mysql+pymysql://notecoin:notecoin@127.0.0.1:3306/notecoin?charset=utf8&autocommit=true"
     # uri = f'sqlite:///{os.path.abspath(os.path.dirname(__file__))}/notecoin.db'
     read_secret(cate1='notecoin', cate2='dataset', cate3='db_path', value=uri)
 
